#ifndef _CHRONOPTICS_TOF_DATA_TYPES_HPP_
#define _CHRONOPTICS_TOF_DATA_TYPES_HPP_

#include <cstdint>

namespace chronoptics {
namespace tof {

struct BGR {
  uint8_t b;
  uint8_t g;
  uint8_t r;
};

static_assert(sizeof(BGR) == 3, "Expected size");

struct XYZ {
  float x;
  float y;
  float z;
  float padding;
};

static_assert(sizeof(XYZ) == 16, "Expected size");

inline bool operator==(const XYZ& lhs, const XYZ& rhs) {
  return lhs.x == rhs.x && lhs.y == rhs.y && lhs.z == rhs.z;
}

struct XYZAmp {
  float x;
  float y;
  float z;
  float amplitude;
};

static_assert(sizeof(XYZAmp) == 16, "Expected size");

inline bool operator==(const XYZAmp& lhs, const XYZAmp& rhs) {
  return lhs.x == rhs.x && lhs.y == rhs.y && lhs.z == rhs.z &&
         lhs.amplitude == rhs.amplitude;
}

struct XYZBGR {
  float x;
  float y;
  float z;
  uint8_t b;
  uint8_t g;
  uint8_t r;
  uint8_t padding;
};

static_assert(sizeof(XYZBGR) == 16, "Expected size");

inline bool operator==(const XYZBGR& lhs, const XYZBGR& rhs) {
  return lhs.x == rhs.x && lhs.y == rhs.y && lhs.z == rhs.z && lhs.b == rhs.b &&
         lhs.g == rhs.g && lhs.r == rhs.r;
}

struct XYZBGRI {
  float x;
  float y;
  float z;
  uint8_t b;
  uint8_t g;
  uint8_t r;
  uint8_t intensity;
};

static_assert(sizeof(XYZBGRI) == 16, "Expected size");

inline bool operator==(const XYZBGRI& lhs, const XYZBGRI& rhs) {
  return lhs.x == rhs.x && lhs.y == rhs.y && lhs.z == rhs.z && lhs.b == rhs.b &&
         lhs.g == rhs.g && lhs.r == rhs.r && lhs.intensity == rhs.intensity;
}

}  // namespace tof
}  // namespace chronoptics

#endif